==> chunksfadein-fabric-3.0.9-1.21.9-sources.jar: com/koteinik/chunksfadein/gui/components/CFISlider.java <==
package com.koteinik.chunksfadein.gui.components;

import com.koteinik.chunksfadein.MathUtils;
import com.koteinik.chunksfadein.config.Config;
import com.koteinik.chunksfadein.gui.GuiUtils;
import com.koteinik.chunksfadein.gui.SettingsScreen;
import com.koteinik.chunksfadein.gui.components.CFIButton.CFIButtonBuilder;
import java.util.function.DoubleConsumer;
import java.util.function.DoubleSupplier;
import java.util.function.Function;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_357;
import net.minecraft.class_7919;
import net.minecraft.class_9110;

public class CFISlider extends class_357 {
	private static final int RESET_BUTTON_W = 40;
	private static final int RESET_BUTTON_H = 20;

	private final Function<Double, class_2561> displayText;
	private final DoubleConsumer applyValue;
	private final DoubleSupplier getValue;
	private final class_9110 tooltip = new class_9110();

	public CFISlider(int x, int y, int width, int height,
	                 DoubleSupplier getValue, DoubleConsumer applyValue, Function<Double, class_2561> displayText,
	                 class_2561 tooltip) {
		super(x, y, width, height, displayText.apply(getValue.getAsDouble()), getValue.getAsDouble());
		this.displayText = displayText;
		this.applyValue = applyValue;
		this.getValue = getValue;

		if (tooltip != null) {
			this.tooltip.method_56138(class_7919.method_47407(tooltip));
			method_47400(class_7919.method_47407(tooltip));
		}
	}

	@Override
	public void method_25344() {
		applyValue.accept(field_22753);
	}

	@Override
	public void method_25346() {
		method_25355(displayText.apply(getValue.getAsDouble()));
	}

	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		super.method_48579(guiGraphics, mouseX, mouseY, partialTick);
	}

	public CFIButton makeResetButton(String key) {
		return new CFIButtonBuilder()
			.width(RESET_BUTTON_W)
			.height(RESET_BUTTON_H)
			.text(SettingsScreen.RESET)
			.onPress(() -> {
				Config.reset(key);

				method_25346();
				field_22753 = getValue.getAsDouble();
			})
			.build();
	}

	public static class CFISliderBuilder {
		private int x = 0;
		private int y = 0;
		private int width = GuiUtils.BUTTON_W;
		private int height = GuiUtils.BUTTON_H;
		private DoubleConsumer applyValue = null;
		private DoubleSupplier getValue = null;
		private Runnable onChange = null;
		private Function<Double, class_2561> displayText = null;
		private class_2561 tooltip = null;

		public CFISliderBuilder() {}

		public CFISliderBuilder x(int x) {
			this.x = x;

			return this;
		}

		public CFISliderBuilder y(int y) {
			this.y = y;

			return this;
		}

		public CFISliderBuilder width(int width) {
			this.width = width;

			return this;
		}

		public CFISliderBuilder height(int height) {
			this.height = height;

			return this;
		}


		public CFISliderBuilder applyValue(DoubleConsumer applyValue) {
			this.applyValue = applyValue;

			return this;
		}

		public CFISliderBuilder getValue(DoubleSupplier getValue) {
			this.getValue = getValue;

			return this;
		}

		public CFISliderBuilder displayText(Function<Double, class_2561> displayText) {
			this.displayText = displayText;

			return this;
		}

		public CFISliderBuilder onChange(Runnable onChange) {
			this.onChange = onChange;

			return this;
		}

		public CFISliderBuilder tooltip(String key) {
			return tooltip(class_2561.method_43471(key));
		}

		public CFISliderBuilder tooltip(class_2561 tooltip) {
			this.tooltip = tooltip;

			return this;
		}

		public CFISlider build() {
			if (onChange != null) {
				DoubleConsumer previousApplyValue = applyValue;

				applyValue = (value) -> {
					if (previousApplyValue != null)
						previousApplyValue.accept(value);

					onChange.run();
				};
			}

			return new CFISlider(x, y, width, height, getValue, applyValue, displayText, tooltip);
		}

		public static CFISliderBuilder range(String textKey, String configKey) {
			return range(textKey, configKey, class_2561.method_43473(), Config.getMin(configKey), Config.getMax(configKey), 0);
		}

		public static CFISliderBuilder range(String textKey, String configKey, int precision) {
			return range(
				textKey,
				configKey,
				class_2561.method_43473(),
				Config.getMin(configKey),
				Config.getMax(configKey),
				precision
			);
		}

		public static CFISliderBuilder range(String textKey, String configKey, class_2561 units) {
			return range(textKey, configKey, units, Config.getMin(configKey), Config.getMax(configKey), 0);
		}

		public static CFISliderBuilder range(String textKey, String configKey, class_2561 units, double min, double max, int precision) {
			return new CFISliderBuilder()
				.displayText(v -> GuiUtils.text(
					textKey,
					String.valueOf(MathUtils.round(MathUtils.lerp(min, max, v), precision))
				).method_10852(units))
				.getValue(() -> MathUtils.rlerp(min, max, Config.getDouble(configKey)))
				.applyValue(v -> Config.setDouble(configKey, MathUtils.lerp(min, max, v)))
				.tooltip(GuiUtils.tooltip(textKey));
		}
	}
}

==> chunksfadein-fabric-3.0.13-1.21.9-sources.jar: com/koteinik/chunksfadein/gui/components/CFISlider.java <==
package com.koteinik.chunksfadein.gui.components;

import com.koteinik.chunksfadein.MathUtils;
import com.koteinik.chunksfadein.config.Config;
import com.koteinik.chunksfadein.crowdin.Translations;
import com.koteinik.chunksfadein.gui.GuiUtils;
import com.koteinik.chunksfadein.gui.SettingsScreen;
import com.koteinik.chunksfadein.gui.components.CFIButton.CFIButtonBuilder;
import java.util.function.DoubleConsumer;
import java.util.function.DoubleSupplier;
import java.util.function.Function;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_357;
import net.minecraft.class_7919;
import net.minecraft.class_9110;

public class CFISlider extends class_357 {
	private static final int RESET_BUTTON_W = 40;
	private static final int RESET_BUTTON_H = 20;

	private final Function<Double, class_2561> displayText;
	private final DoubleConsumer applyValue;
	private final DoubleSupplier getValue;
	private final class_9110 tooltip = new class_9110();

	public CFISlider(int x, int y, int width, int height,
	                 DoubleSupplier getValue, DoubleConsumer applyValue, Function<Double, class_2561> displayText,
	                 class_2561 tooltip) {
		super(x, y, width, height, displayText.apply(getValue.getAsDouble()), getValue.getAsDouble());
		this.displayText = displayText;
		this.applyValue = applyValue;
		this.getValue = getValue;

		if (tooltip != null) {
			this.tooltip.method_56138(class_7919.method_47407(tooltip));
			method_47400(class_7919.method_47407(tooltip));
		}
	}

	@Override
	public void method_25344() {
		applyValue.accept(field_22753);
	}

	@Override
	public void method_25346() {
		method_25355(displayText.apply(getValue.getAsDouble()));
	}

	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		super.method_48579(guiGraphics, mouseX, mouseY, partialTick);
	}

	public CFIButton makeResetButton(String key) {
		return new CFIButtonBuilder()
			.width(RESET_BUTTON_W)
			.height(RESET_BUTTON_H)
			.text(SettingsScreen.RESET)
			.onPress(() -> {
				Config.reset(key);

				method_25346();
				field_22753 = getValue.getAsDouble();
			})
			.build();
	}

	public static class CFISliderBuilder {
		private int x = 0;
		private int y = 0;
		private int width = GuiUtils.BUTTON_W;
		private int height = GuiUtils.BUTTON_H;
		private DoubleConsumer applyValue = null;
		private DoubleSupplier getValue = null;
		private Runnable onChange = null;
		private Function<Double, class_2561> displayText = null;
		private class_2561 tooltip = null;

		public CFISliderBuilder() {}

		public CFISliderBuilder x(int x) {
			this.x = x;

			return this;
		}

		public CFISliderBuilder y(int y) {
			this.y = y;

			return this;
		}

		public CFISliderBuilder width(int width) {
			this.width = width;

			return this;
		}

		public CFISliderBuilder height(int height) {
			this.height = height;

			return this;
		}


		public CFISliderBuilder applyValue(DoubleConsumer applyValue) {
			this.applyValue = applyValue;

			return this;
		}

		public CFISliderBuilder getValue(DoubleSupplier getValue) {
			this.getValue = getValue;

			return this;
		}

		public CFISliderBuilder displayText(Function<Double, class_2561> displayText) {
			this.displayText = displayText;

			return this;
		}

		public CFISliderBuilder onChange(Runnable onChange) {
			this.onChange = onChange;

			return this;
		}

		public CFISliderBuilder tooltip(String key) {
			return tooltip(Translations.translatable(key));
		}

		public CFISliderBuilder tooltip(class_2561 tooltip) {
			this.tooltip = tooltip;

			return this;
		}

		public CFISlider build() {
			if (onChange != null) {
				DoubleConsumer previousApplyValue = applyValue;

				applyValue = (value) -> {
					if (previousApplyValue != null)
						previousApplyValue.accept(value);

					onChange.run();
				};
			}

			return new CFISlider(x, y, width, height, getValue, applyValue, displayText, tooltip);
		}

		public static CFISliderBuilder range(String textKey, String configKey) {
			return range(textKey, configKey, class_2561.method_43473(), Config.getMin(configKey), Config.getMax(configKey), 0);
		}

		public static CFISliderBuilder range(String textKey, String configKey, int precision) {
			return range(
				textKey,
				configKey,
				class_2561.method_43473(),
				Config.getMin(configKey),
				Config.getMax(configKey),
				precision
			);
		}

		public static CFISliderBuilder range(String textKey, String configKey, class_2561 units) {
			return range(textKey, configKey, units, Config.getMin(configKey), Config.getMax(configKey), 0);
		}

		public static CFISliderBuilder range(String textKey, String configKey, class_2561 units, double min, double max, int precision) {
			return new CFISliderBuilder()
				.displayText(v -> GuiUtils.text(
					textKey,
					String.valueOf(MathUtils.round(MathUtils.lerp(min, max, v), precision))
				).method_10852(units))
				.getValue(() -> MathUtils.rlerp(min, max, Config.getDouble(configKey)))
				.applyValue(v -> Config.setDouble(configKey, MathUtils.lerp(min, max, v)))
				.tooltip(GuiUtils.tooltip(textKey));
		}
	}
}
